@@ -1,5 +1,5 @@
 package Util::Medley::String;
-$Util::Medley::String::VERSION = '0.041';
+$Util::Medley::String::VERSION = '0.042';
 use Modern::Perl;
 use Moose;
 use namespace::autoclean;
@@ -14,7 +14,7 @@ Util::Medley::String - utility methods for working with strings
 
 =head1 VERSION
 
-version 0.041
+version 0.042
 
 =head1 SYNOPSIS
 
@@ -152,6 +152,49 @@ multi method isInt (Str $str) {
 	return $self->isInt(str => $str);	
 }
 
+=head2 isUpper
+
+todo
+
+=over
+
+=item usage:
+
+  $bool = $util->isUpper($str);
+
+  $bool = $util->isUpper(str => $str);
+
+=item args:
+
+=over
+
+=item str [Str]
+
+The string you wish to check for uppercase.
+
+=back
+
+=back
+ 
+=cut
+
+multi method isUpper (Str :$str!) {
+
+    my $lookfor = 'A-Z0-9_()';
+    
+    if ($str =~ /^[$lookfor]+$/) {
+        return 1;   
+    }
+    
+    return 0;
+}
+
+multi method isUpper (Str $str) {
+
+    return $self->isUpper(str => $str);   
+}
+
+
 =head2 lTrim
 
 Just a pass-through to String::Util::lTrim.
